@@ -355,6 +355,32 @@
 #define __NR_statx	397
 #define __NR_rseq	398
 #define __NR_io_pgetevents	399
+#define __NR_migrate_pages	400
+#define __NR_kexec_file_load	401
+#define __NR_clock_gettime64	403
+#define __NR_clock_settime64	404
+#define __NR_clock_adjtime64	405
+#define __NR_clock_getres_time64	406
+#define __NR_clock_nanosleep_time64	407
+#define __NR_timer_gettime64	408
+#define __NR_timer_settime64	409
+#define __NR_timerfd_gettime64	410
+#define __NR_timerfd_settime64	411
+#define __NR_utimensat_time64	412
+#define __NR_pselect6_time64	413
+#define __NR_ppoll_time64	414
+#define __NR_io_pgetevents_time64	416
+#define __NR_recvmmsg_time64	417
+#define __NR_mq_timedsend_time64	418
+#define __NR_mq_timedreceive_time64	419
+#define __NR_semtimedop_time64	420
+#define __NR_rt_sigtimedwait_time64	421
+#define __NR_futex_time64	422
+#define __NR_sched_rr_get_interval_time64	423
+#define __NR_pidfd_send_signal	424
+#define __NR_io_uring_setup	425
+#define __NR_io_uring_enter	426
+#define __NR_io_uring_register	427
 
 #define __ARM_NR_breakpoint	0x0f0001
 #define __ARM_NR_cacheflush	0x0f0002
@@ -720,3 +746,29 @@
 #define SYS_statx	397
 #define SYS_rseq	398
 #define SYS_io_pgetevents	399
+#define SYS_migrate_pages	400
+#define SYS_kexec_file_load	401
+#define SYS_clock_gettime64	403
+#define SYS_clock_settime64	404
+#define SYS_clock_adjtime64	405
+#define SYS_clock_getres_time64	406
+#define SYS_clock_nanosleep_time64	407
+#define SYS_timer_gettime64	408
+#define SYS_timer_settime64	409
+#define SYS_timerfd_gettime64	410
+#define SYS_timerfd_settime64	411
+#define SYS_utimensat_time64	412
+#define SYS_pselect6_time64	413
+#define SYS_ppoll_time64	414
+#define SYS_io_pgetevents_time64	416
+#define SYS_recvmmsg_time64	417
+#define SYS_mq_timedsend_time64	418
+#define SYS_mq_timedreceive_time64	419
+#define SYS_semtimedop_time64	420
+#define SYS_rt_sigtimedwait_time64	421
+#define SYS_futex_time64	422
+#define SYS_sched_rr_get_interval_time64	423
+#define SYS_pidfd_send_signal	424
+#define SYS_io_uring_setup	425
+#define SYS_io_uring_enter	426
+#define SYS_io_uring_register	427
